package meerkat.bulletinboard;

import meerkat.crypto.Digest;
import meerkat.protobuf.BulletinBoardAPI.*;

import java.util.List;

/**
 * Created by Arbel Deutsch Peled on 18-Dec-15.
 * Extends the Digest interface with a method for digesting Batch messages
 */
public interface BulletinBoardDigest extends Digest {

    /**
     * Update the digest with the batch message data (ignore the signature)
     * The digest only uses the part the signatures are computed on for this operation
     * @param completeBatch is the batch message that needs to be digested
     */
    public void updateCompleteBatch(BulletinBoardMessage completeBatch);

    /**
     * Update the digest with a BulletinBoardMessage that contains only the metadata of a batch message
     * The digest only uses the part the signatures are computed on for this operation
     * This operation is necessary before beginning to digest the actual data
     * @param batchStub contains the metadata
     */
    public void updateBatchStub(BulletinBoardMessage batchStub);

    /**
     * Update the digest with the batch message data (ignore the signature)
     * @param completeBatch is the batch message that needs to be digested
     */
    public void updateCompleteBatch(UnsignedBulletinBoardMessage completeBatch);

    /**
     * Update the digest with a BulletinBoardMessage that contains only the metadata of a batch message
     * This operation is necessary before beginning to digest the actual data
     * @param batchStub contains the metadata
     */
    public void updateBatchStub(UnsignedBulletinBoardMessage batchStub);

}
